:orphan:

Welcome to Nereid
==================

Welcome to Nereid's documentation.  This documentation is divided into
different parts.  We recommend that you get started with
:ref:`installation` and then head over to the :ref:`quickstart`.
Besides the quickstart, there is also a more detailed :ref:`tutorial` that
shows how to create a complete (albeit small) application with Nereid.  If
you'd rather dive into the internals of Nereid, check out
the :ref:`api` documentation.
 
The main dependencies of Nereid are `Flask`_ and `Tryton`_. In addition
Nereid uses `Babel`_ for internationalisation, `Speak Later`_ for lazy
strings, `WTForms`_ for form building and `ccy`_ for currency mapping. 

The template engine used is `Jinja2`_ and `Flask`_ is built over `Werkzeug`_ 
a WSGI toolkit.These libraries are not documented here.  If you want to dive 
into their documentation, check out the following links:

-   `Flask Documentation <http://flask.pocoo.org/docs/>`_
-   `Tryton Documentation <http://doc.tryton.org/2.4/>`_
-   `Babel Documentation <http://babel.edgewall.org/wiki/Documentation>`_
-   `Speaklater Documentation <http://pypi.python.org/pypi/speaklater>`_
-   `WTForms Documentation <http://wtforms.simplecodes.com/docs/dev/>`_
-   `CCY documentation <http://pypi.python.org/pypi/ccy>`_
-   `Jinja2 Documentation <http://jinja.pocoo.org/2/documentation/>`_

If this documentation reminds you of `Flask`_ documentation, it is not a
coincidence, it has been designed so to ease up the learning curve for
anyone who knows both `Flask`_ and `Tryton`_.

.. _Flask: http://flask.pocoo.org/
.. _Tryton: http://www.tryton.org/index.html
.. _WTForms: http://wtforms.simplecodes.com/docs/dev/
.. _Babel: http://babel.edgewall.org/
.. _Speak Later: http://pypi.python.org/pypi/speaklater
.. _ccy: http://pypi.python.org/pypi/ccy
.. _Jinja2: http://jinja.pocoo.org/2/
.. _Werkzeug: http://werkzeug.pocoo.org/

.. include:: contents.rst.inc
